diff graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/CompilationResult.java @ 15180:7a9531f50cd8

renamed com.oracle.graal.api.code.CompilationResult.frameSize to totalFrameSize
author twisti
date Wed, 16 Apr 2014 15:04:35 -1000
parents f24d578e63a9
children 1b82cd9e72e9
line wrap: on
line diff
--- a/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/CompilationResult.java	Thu Apr 17 01:57:46 2014 +0200
+++ b/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/CompilationResult.java	Wed Apr 16 15:04:35 2014 -1000
@@ -460,7 +460,7 @@
     private final List<ExceptionHandler> exceptionHandlers = new ArrayList<>();
     private final List<Mark> marks = new ArrayList<>();
 
-    private int frameSize = -1;
+    private int totalFrameSize = -1;
     private int customStackAreaOffset = -1;
     private int registerRestoreEpilogueOffset = -1;
 
@@ -525,23 +525,24 @@
     }
 
     /**
      * The frame size of the method in bytes. This includes the return address pushed onto the
      * stack, if any.
      *
      * @return the frame size
      */
-    public int getFrameSize() {
-        assert frameSize != -1 : "frame size not yet initialized!";
-        return frameSize;
+    public int getTotalFrameSize() {
+        assert totalFrameSize != -1 : "frame size not yet initialized!";
+        return totalFrameSize;
     }
 
     /**
      * Sets the frame size in bytes. This includes the return address pushed onto the stack, if any.
      *
      * @param size the size of the frame in bytes
      */
-    public void setFrameSize(int size) {
-        frameSize = size;
+    public void setTotalFrameSize(int size) {
+        totalFrameSize = size;
     }
 
     /**
@@ -525,23 +525,24 @@
 
     /**
-     * The frame size of the method in bytes. This includes the return address pushed onto the
+     * The total frame size of the method in bytes. This includes the return address pushed onto the
      * stack, if any.
      *
@@ -525,23 +525,24 @@
 
     /**
-     * Sets the frame size in bytes. This includes the return address pushed onto the stack, if any.
+     * Sets the total frame size in bytes. This includes the return address pushed onto the stack,
+     * if any.
      *
      * @param size the size of the frame in bytes